cumulusci.tasks.bulkdata.tests package
======================================

Submodules
----------

cumulusci.tasks.bulkdata.tests.dummy\_data\_factory module
----------------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.tests.dummy_data_factory
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.tests.test\_base\_generate\_data\_tasks module
-----------------------------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.tests.test_base_generate_data_tasks
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.tests.test\_bulkdata module
----------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.tests.test_bulkdata
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.tests.test\_delete module
--------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.tests.test_delete
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.tests.test\_factory\_utils module
----------------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.tests.test_factory_utils
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata.tests.test\_utils module
-------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.tests.test_utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.bulkdata.tests
    :members:
    :undoc-members:
    :show-inheritance:
